@@ -12,22 +12,37 @@ class Grammar(object):
         ('right', 'DOT', 'LBRACKET'),
     )
 
-    def p_jmespath_expression(self, p):
-        """ expression : expression DOT expression"""
-        p[0] = ast.SubExpression(p[1], p[3])
+    def p_jmespath_subexpression(self, p):
+        """ expression : expression DOT expression
+                       | STAR
+        """
+        if len(p) == 2:
+            # Then this is the STAR rule.
+            p[0] = ast.WildcardValues()
+        else:
+            # This is the expression DOT expression rule.
+            p[0] = ast.SubExpression(p[1], p[3])
 
     def p_jmespath_index(self, p):
-        """expression : expression LBRACKET NUMBER RBRACKET
-                      | expression LBRACKET STAR RBRACKET
+        """expression : expression bracket-spec
+                      | bracket-spec
         """
-        if p[3] == '*':
-            p[0] = ast.ElementsBranch(p[1])
-        else:
-            p[0] = ast.SubExpression(p[1], ast.Index(p[3]))
+        if len(p) == 3:
+            p[0] = ast.SubExpression(p[1], p[2])
+        elif len(p) == 2:
+            # Otherwise this is just a bracket-spec, which is valid as a root
+            # level node (e.g. [2]) so we just assign the root node to the
+            # bracket-spec.
+            p[0] = p[1]
 
-    def p_jmespath_wildcard(self, p):
-        """expression : expression DOT STAR"""
-        p[0] = ast.ValuesBranch(p[1])
+    def p_jmespath_bracket_specifier(self, p):
+        """bracket-spec : LBRACKET STAR RBRACKET
+                        | LBRACKET NUMBER RBRACKET
+        """
+        if p[2] == '*':
+            p[0] = ast.WildcardIndex()
+        else:
+            p[0] = ast.Index(p[2])
 
     def p_jmespath_identifier(self, p):
         """expression : IDENTIFIER
@@ -67,7 +82,8 @@ class Parser(object):
         if cached is not None:
             return cached
         lexer = ply.lex.lex(module=self._lexer_definition(),
-                            debug=self._debug)
+                            debug=self._debug,
+                            reflags=self._lexer_definition.reflags)
         grammar = self._grammar()
         grammar.tokens = self._lexer_definition.tokens
         parser = ply.yacc.yacc(module=grammar, debug=self._debug,
