@@ -10,31 +10,37 @@ class TestAST(unittest.TestCase):
         pass
 
     def test_field(self):
+        # jmespath: foo
         field = ast.Field('foo')
         match = field.search({'foo': 'bar'})
         self.assertEqual(match, 'bar')
 
     def test_field_no_match(self):
+        # jmespath: foo
         field = ast.Field('foo')
         match = field.search({'bar': 'bar'})
         self.assertEqual(match, None)
 
     def test_field_when_dict(self):
+        # jmespath: foo
         field = ast.Field('foo')
         match = field.search({'foo': {'bar': 'baz'}})
         self.assertEqual(match, {'bar': 'baz'})
 
     def test_field_when_list(self):
+        # jmespath: foo
         field = ast.Field('foo')
         match = field.search({'foo': ['bar', 'baz']})
         self.assertEqual(match, ['bar', 'baz'])
 
     def test_dot_syntax(self):
+        # jmespath: foo.bar
         child = ast.SubExpression(ast.Field('foo'), ast.Field('bar'))
         match = child.search({'foo': {'bar': 'correct', 'baz': 'wrong'}})
         self.assertEqual(match, 'correct')
 
     def test_multiple_nestings(self):
+        # jmespath: foo.bar.baz
         child = ast.SubExpression(
             ast.Field('foo'),
             ast.SubExpression(ast.Field('bar'), ast.Field('baz')))
@@ -49,24 +55,28 @@ class TestAST(unittest.TestCase):
         self.assertEqual(child.search(''), None)
 
     def test_index(self):
+        # jmespath: foo[1]
         child = ast.SubExpression(ast.Field('foo'), ast.Index(1))
         match = child.search(
             {'foo': ['one', 'two', 'three']})
         self.assertEqual(match, 'two')
 
     def test_bad_index(self):
+        # jmespath: foo[100]
         child = ast.SubExpression(ast.Field('foo'), ast.Index(100))
         match = child.search(
             {'foo': ['one', 'two', 'three']})
         self.assertEqual(match, None)
 
     def test_negative_index(self):
+        # jmespath: foo[-1]
         child = ast.SubExpression(ast.Field('foo'), ast.Index(-1))
         match = child.search(
             {'foo': ['one', 'two', 'last']})
         self.assertEqual(match, 'last')
 
     def test_index_with_children(self):
+        # jmespath: foo.bar[-1]
         child = ast.SubExpression(
             ast.Field('foo'),
             ast.SubExpression(ast.Field('bar'), ast.Index(-1)))
@@ -75,6 +85,7 @@ class TestAST(unittest.TestCase):
         self.assertEqual(match, 'last')
 
     def test_multiple_indices(self):
+        # jmespath: foo[1].bar[1]
         child = ast.SubExpression(
             ast.SubExpression(
                 ast.Field('foo'), ast.Index(1)),
@@ -85,13 +96,14 @@ class TestAST(unittest.TestCase):
         self.assertEqual(match, 'one')
 
     def test_index_with_star(self):
-        child = ast.ElementsBranch(ast.Field('foo'))
+        # jmespath: foo[*]
+        child = ast.SubExpression(ast.Field('foo'), ast.WildcardIndex())
         match = child.search({'foo': ['one', 'two']})
         self.assertEqual(match, ['one', 'two'])
 
-
     def test_associative(self):
         data = {'foo': {'bar': ['one']}}
+        # jmespath: foo.bar[0]
         first = ast.SubExpression(
             ast.Field('foo'),
             ast.SubExpression(ast.Field('bar'), ast.Index(0)))
@@ -105,7 +117,7 @@ class TestAST(unittest.TestCase):
         data = {'foo': {'bar': {'get': 'one'}, 'baz': {'get': 'two'}}}
         # ast for "foo.*.get"
         expression = ast.SubExpression(
-            ast.ValuesBranch(ast.Field('foo')),
+            ast.SubExpression(ast.Field('foo'), ast.WildcardValues()),
             ast.Field('get'))
         match = expression.search(data)
         self.assertEqual(sorted(match), ['one', 'two'])
@@ -114,7 +126,7 @@ class TestAST(unittest.TestCase):
     def test_wildcard_branches_with_index(self):
         # foo[*].bar
         child = ast.SubExpression(
-            ast.ElementsBranch(ast.Field('foo')),
+            ast.SubExpression(ast.Field('foo'), ast.WildcardIndex()),
             ast.Field('bar')
         )
         match = child.search(
@@ -125,7 +137,7 @@ class TestAST(unittest.TestCase):
     def test_index_with_multi_match(self):
         # foo[*].bar[0]
         child = ast.SubExpression(
-            ast.ElementsBranch(ast.Field('foo')),
+            ast.SubExpression(ast.Field('foo'), ast.WildcardIndex()),
             ast.SubExpression(
                 ast.Field('bar'),
                 ast.Index(0)))
